/*
 * Writes all signals in a DDA from the Minerva/DataSignals cached PPF to the actual PPF system.
 *
 * Time vectors are compared 
 *
 *
 * 2008-04-09: Alex Meakins <alex.meakins@jet.uk>
 *             Initial Version
 *
*/

#include <iostream>
#include <fstream>
#include <string>
#include <cmath>
#include <cstdio>
#include "ppfc++.hpp"

#include "/work/code/minerva/DataSignals/csrc/DataSignals.h"

using namespace std;
using namespace ppf;

int main(int argc, char *argv[])
{
	long shot;
	datatype a;

	if (argc != 3)
	{
		cout << "Usage: cacheToPPF [ppfDir] \n";
		return 1;
	}

	shot = atol(argv[2]);

	// 1st version of code: simple (shorthand) version 
	try
	{
		ppfdb.connect();
		ppfdb.connect(argv[1], ppf::write);

		ppfdb.read(a, shot, "EQUI", "Q");

		ppfdb.create(shot);
		ppfdb.write(a, "TEST", "A");

		for (long i=0;i<a.sizeT();i++) a.setT(i, a.getT(i) - 0.001);

		ppfdb.write(a, "TEST", "B");
		ppfdb.commit();
	}
	catch (ppf_error &e)
	{
		cout << e.message << " Code=" << e.code << ", Routine=" << e.method << endl;
		exit(1);
	}
	
	// 2nd version of code: verbose (explicit) version 
	try
	{
		ppfdb.connect("JETPPF", ppf::read);
		ppfdb.connect(argv[1], ppf::write);

		ppfdb.read(a, shot, "EQUI", "Q");

		ppfdb.create(shot, 1, "Test PPF");
		ppfdb.write(a, "TEST", "A", ppf::tvector | ppf::xvector);
		
		for (long t=0;t<a.sizeT();t++) a.setT(t, a.getT(t) - 0.001);

		ppfdb.write(a, "TEST", "B", ppf::tvector | ppf::xvector);
		ppfdb.closeDDA(1, "Test DDA");
		ppfdb.commit("PPFTEST", 1);
	}
	catch (ppf_error &e)
	{
		cout << e.message << " Code=" << e.code << ", Routine=" << e.method << endl;
		exit(1);
	}
	
   	return 0;
}


