/***********************************************************/
/* Name: ppf.h                                             */
/*                                                         */
/* Description: Header file for user callable ppf routines */
/*                                                         */
/* Arguments:   None                                       */
/*                                                         */
/* Returns:     void                                       */
/*                                                         */
/* Author:      R Layne (extracted from ppfclient.h)       */
/*                                                         */
/* Change Log:                                             */
/*
 * $Log: ppf.h,v $
 * Revision 2.37  2008/06/27 10:26:38  ncook
 * Added public definitions of PDSTAT and ppfOwnerInfo
 *
 * Revision 2.36  2006/08/04 14:47:37  ncook
 * Swapped ordering of indat and nrmax arguments in PPFOPN declaration because
 * they were in the wrong order.
 * General tidy up
 *
 * Revision 2.35  2004/07/20 16:23:58  ncook
 * Added windows prototype for PPFPOK
 *
 * Revision 2.34  2004/01/21 11:03:13  ncook
 * Added prototypes for PDNEWL, PDNEWN and PDNTIM
 *
 * Revision 2.33  2003/11/27 12:29:44  ncook
 * Added prototypes for ppfsum_client and ppfgmd
 *
 * Revision 2.32  2003/05/30 15:59:56  ncook
 * Corrected error in WinNT version of pdauth prototype declaration
 *
 * Revision 2.31  2003/05/28 08:18:16  ncook
 * Added prototypes for pdmseq, pdmodl, pdmodn and pdmtim
 *
 * Revision 2.30  2003/02/14 08:38:45  ncook
 * Modified prototype of pdlusr so that caUserNames is 1D rather than 2D CVS: ----------------------------------------------------------------------
 *
 * Revision 2.29  2003/01/28 14:43:06  ncook
 * Added prototypes for pdmsdt, pdlusr and ppfsiz
 *
 * Revision 2.28  2002/11/25 10:00:52  ral
 * Remove ppfrcl and associated functions and defines
 *
 * Revision 2.27  2002/11/12 10:56:39  ral
 * Add ppfrcl
 *
 * Revision 2.26  2002/11/04 15:13:33  ncook
 * Changed name of ppfdel_ppfren_client to ppfListPPFsOwnedByUser
 *
 * Revision 2.25  2002/10/30 11:34:16  ncook
 * Modified prototype of pdauth and added new prototype for ppfdel_ppfren_client
 *
 * Revision 2.24  2002/10/21 09:25:12  ncook
 * Added ppfdti prototypes
 *
 * Revision 2.23  2002/08/15 13:15:53  ncook
 * Added prototype for pdauth
 *
 * Revision 2.22  2002/06/25 15:02:38  ncook
 * Modified prototype of ppfseq to reflect the passing of modification
 * times as integer values rather than strings
 *
 * Revision 2.21  2002/06/24 16:30:18  ncook
 * Added prototype for ppfseq
 *
 * Revision 2.20  2002/03/06 15:44:42  ncook
 * Added prototypes for pdtinf
 *
 * Revision 2.19  2002/02/20 14:32:54  ral
 * Correct ppfmod win32 prototype
 *
 * Revision 2.18  2002/02/19 14:45:57  ncook
 * Added ppfmod prototype
 *
 * Revision 2.17  2002/02/01 14:38:33  ral
 * Add ppfondisk
 *
 * Revision 2.16  2001/12/10 14:10:09  ncook
 * Removed prototypes for the PPF utility routines to ppfclient.h
 *
 * Revision 2.15  2001/12/07 10:32:33  ncook
 * Added iOrderFormat to argument list of ppfbro_client
 *
 * Revision 2.14  2001/12/05 16:23:37  ncook
 * Added prototypes for ppfbro_client, ppfdda_client, ppfsum_client and
 * ppftab_client to replace cppfbro, cddadat, cppfsum and cppftab
 *
 * Revision 2.13  2001/10/12 12:11:46  ncook
 * Added extra listing parameter to prototype of cppfsum
 *
 * Revision 2.12  2001/09/26 08:20:17  ncook
 * Added prototypes and aliases for PPF utility routines.  These all begin with the
 * letter 'C' to denote they are client side versions of the utility routine which
 * shares the same name
 *
 * Revision 2.10  2001/09/18 07:48:45  ncook
 * Added prototypes and alias for PPFGID
 *
 * Revision 2.9  2001/08/23 09:57:50  ncook
 * Changed name of ppfnew to ppfnewpulse in prototypes
 *
 * Revision 2.8  2001/08/21 08:48:38  ral
 * Remove obsolete ppfsum prototype
 *
 * Revision 2.7  2001/08/20 08:44:00  ncook
 * Modified data and time arguments in ppfnew prototypes to be longs
 *
 * Revision 2.6  2001/08/08 13:58:29  ncook
 * Added prototype for ppfnew - used to automatically insert a new pulse before
 * chain1 runs
 *
 * Revision 2.5  2001/07/31 12:54:26  ral
 * Remove commented out dtconv prototype
 *
 * Revision 2.4  2001/07/25 08:33:21  ncook
 * Removed prototype of PPFSUM as replaced by CPPFSUM
 *
 * Revision 2.3  2001/07/24 09:30:55  ncook
 * Added prototype for cppfsum.c and modified prototype for ppfsum.c
 *
 * Revision 2.2  2001/06/25 15:28:13  ral
 * Remove declarations of ppfdumpstateinfo from win32 build
 *
 * Revision 2.1  2001/06/19 08:38:40  drobson
 * C++ style comments removed
 *
 * Revision 2.0  2001/06/18 13:32:50  drobson
 * Brought up to version 2.0 prior to release
 *
 * Revision 1.10  2001/06/18 08:32:23  ncook
 * Modified prototype of ppfsum
 *
 * Revision 1.9  2001/06/16 13:58:19  ncook
 * Added prototype for ppfren
 *
 * Revision 1.8  2001/06/15 16:04:52  ral
 * Add ppfkil
 *
 * Revision 1.7  2001/06/07 10:28:20  ncook
 * Added prototype of PPFSUM
 *
 * Revision 1.6  2001/06/01 11:39:04  drobson
 * Mods to add password authentication status checking
 *
 * Revision 1.5  2001/05/28 15:17:53  ral
 * Add PPFERR and PPFEND
 *
 * Revision 1.4  2001/05/24 09:52:04  ral
 * Add ddalen parameter
 *
 * Revision 1.2  2001/05/10 15:22:22  ral
 * Correct ppfgo declaration
 *
 * Revision 1.1  2001/05/10 15:18:53  ral
 * Initial load -extracted from ppfclient.h
 *
*/
/***********************************************************/

/* definitions for different linkages */

#ifndef _WIN32
#define DDACLO             ddaclo_
#define DDAINF             ddainf_
#define DDAMIN             ddamin_
#define PDAINF             pdainf_
#define PDAUTH             pdauth_
#define PDINFO             pdinfo_
#define PDLPPF             pdlppf_
#define PDLUSR             pdlusr_
#define PDMSDT             pdmsdt_
#define PDMSHT             pdmsht_
#define PDREFR             pdrefr_
#define PDSRCH             pdsrch_ 
#define PDSTD              pdstd_
#define PDTINF             pdtinf_
#define PPFABO             ppfabo_
#define PPFCLO             ppfclo_ 
#define PPFDAT             ppfdat_
#define PPFDCM             ppfdcm_
#define PPFDDA             ppfdda_
#define PPFDEL             ppfdel_
#define PPFDUMPSTATEINFO   ppfdumpstateinfo_
#define PPFDUMPBACKUPSTATEINFO   ppfbackupdumpstateinfo_
#define PPFDTI             ppfdti_
#define PPFEND             ppfend_
#define PPFERR             ppferr_
#define PPFGET             ppfget_ 
#define PPFGID             ppfgid_
#define PPFGO              ppfgo_
#define PPFGQI             ppfgqi_
#define PPFGSF             ppfgsf_
#define PPFGTS             ppfgts_
#define PPFINF             ppfinf_
#define PPFINI             ppfini_
#define PPFKIL             ppfkil_
#define PPFLISTPPFSOWNEDBYUSER  ppflistppfsownedbyuser_
#define PPFMOD             ppfmod_
#define PPFNEWPULSE        ppfnewpulse_
#define PPFONDISK          ppfondisk_
#define PPFOWNERINFO       ppfownerinfo_
#define PPFOPN             ppfopn_ 
#define PPFPOK             ppfpok_
#define PPFPRR             ppfprr_
#define PPFPWD             ppfpwd_
#define PPFRCM             ppfrcm_
#define PPFREN             ppfren_
#define PPFSEQ             ppfseq_
#define PPFSIZ             ppfsiz_
#define PPFSQI             ppfsqi_
#define PPFSSF             ppfssf_
#define PPFSSR             ppfssr_
#define PPFUID             ppfuid_ 
#define PDLUSR             pdlusr_
#define PPFWCM             ppfwcm_
#define PPFWRI             ppfwri_
#define PDMSEQ             pdmseq_
#define PDMODN             pdmodn_
#define PDMTIM             pdmtim_
#define PDMODL             pdmodl_
#define PPFGMD             ppfgmd_
#define PDNEWN             pdnewn_
#define PDNEWL             pdnewl_
#define PDNTIM             pdntim_
#define PDSTAT             pdstat_

/* User callable PPF client routines */

void DDAINF (int *ishot, char *dda, int *nwcom, char *ddacom,
	     int *ndt, char *dtnams, int *lstv, int *iErr,
	     unsigned int idda_len, unsigned int iddacom_len,
	     unsigned int idtnams_len);

void DDACLO (int *istat, int *nwc, char *icom, int *ierr, 
	     unsigned int iCommentLength);

void DDAMIN (char *DDA, int *MRGINF, int *NWCOM, char *PPFCOM, int *ierr,
	     unsigned int DDAlen, unsigned int PPFCOMlen);

void PDAINF (char *prgnam, int *ipvers, char *ppfnam, 
	     int *ierr, unsigned int prgnamlen, unsigned int ppfnamlen);

void PDAUTH (char *caUserName,  int *iNumberOfDDAs, int *iNumberOfAlias, 
	     int *iNumberOfWriteTo, int *iPrivate, int *iPublic,
	     char *caDDANames, char *caAlias, char *caWriteTo, int *iErr, 
	     unsigned int iUserNameLength, unsigned int DDANameLength,
	     unsigned int iAliasLength, unsigned int iWriteToLength);

void PDINFO (int *ishot, int *iseq, int *info, char *cnfo, char *ddal, 
	     int *istl, char *pcom, char *pdsn, int *ierr, 
	     unsigned int cnfo_length, unsigned int ddal_length,
	     unsigned int pcom_length, unsigned int pdsn_length);

void PDLPPF (int *ishot, int *iuid, int *idup, int *nseq, int *lseq, int *ldda,
	     int *ndda, char *cdda, int *ierr, unsigned int cdda_length);

void PDLUSR (int *iShot, char *caDDA, int *iNumberOfUsers, char *caUserNames,
	     int *iErr, unsigned int DDALen, unsigned int UserNameLen);

void PDMODL (int *iDate, char *caTime, int *iNPPFs, int *iaShot, int *iaSeq,
	     char *caOwner, int *iaModDate, char *caModTime, int *iErr,
	     unsigned int TimeLen, unsigned int OwnerLen,
	     unsigned int ModTimeLen);

void PDMODN (int *iDate, char *caTime, int *iNPPFs, int *iErr,
	     unsigned int TimeLen);

void PDMSEQ (int *iShot, char *caOwner, char *caDDA, int *iSequence, 
	     int *iErr, unsigned int OwnerLen, unsigned int DDALen);

void PDMSHT (int *LastShot);

void PDMSDT (int *iDate, char *caTime, int *iPulse, int *iErr,
	     unsigned int TimeLen);

void PDMTIM (char *caApplication, int *iErr, unsigned int iAppLength);

void PDNEWL (int *iDate, char *caTime, char *caUserName, 
	     int *iNDDAs, int *iaShot, int *iaSeq, char *caOwners,
	     char *caDDANames, int *iErr,
	     unsigned int TimeLen, unsigned int UserLen,  
	     unsigned int OwnerLen, unsigned int DDALen);

void PDNEWN (int *iDate, char *caTime, char *caOwner, int *iNDDAs, int *iErr,
	     unsigned int TimeLen, unsigned int OwnLen);

void PDNTIM (char *caApplication, int *iErr, unsigned int iAppLength);

void PDREFR (int *irefr);

void PDSRCH (int *ishot, char *dda, int *iseq, int *ndda, char *ddalst, 
	     int *ierr, unsigned int dda_length, unsigned int ddalst_length);

void PDSTAT (char *caLoginName, int *iStatus, char *caStatusString, 
	     int *iErr, unsigned int iLoginLength, unsigned int iStatusLength);

void PDSTD(int *iShot, int *iTime, int *iDate, int *iErr);

void PDTINF (int *ishot, char *dda, int *ndt, char *dtnams,
	     int *lxtv, char *caDataTypeComments, int *iErr, 
	     unsigned int idda_len, 
	     unsigned int idtnams_len, 
	     unsigned int idatatypecommentlength);

void PPFABO (int *ierr);

void PPFCLO (int *ISHOT, int *ISEQ, int *idum, char *PRGNAM,
	     int *IPVERS,int *IERR, unsigned int prgnamlen);

void PPFDAT (int *ishot, int *iseq, char *dda, char *dtype, int *nx, int *nt,
	     float *data, float *x, float *t, int *ierr,
	     unsigned int dda_length, unsigned int dtype_length);

void PPFDCM (int *shot, int *seq, char *dda, char *dtype, int *ierr, 
	     unsigned int dda_len, unsigned int dtype_len);

void PPFDDA (int *ishot, char *dda, int *iseq, int *nseq, int *ierr, 
	     unsigned int dda_length);

void PPFDEL (int *iShot, int *iSeq, int *iErr);

void PPFLISTPPFSOWNEDBYUSER (int iStartShot, int iEndShot, 
			     char *caUserName, 
			     int *iNumberOfSequences, 
			     int *iaPulseNumbers, 
			     int *iaSequenceNumbers, int *iErr);

void PPFDTI (int *iShot, int *iSequence, char *caDDA, char *caDataType,
	     int *iNX, int *iNT, char *caFormat, char *caUnits, 
	     char *caComment, int *iSystemStatus, int *iUserStatus, int *iErr, 
	     unsigned int DDALen, unsigned int DatatypeLen, 
	     unsigned int FormatLen, unsigned int UnitsLen, 
	     unsigned int CommentLen);

void PPFEND (int *ishot, int *iseq, int* luint, int *ierr);

void PPFERR (char *RNAME, int *ierrcode, char *MSG, int *ierr,            
	     unsigned int RNAMElen, unsigned int MSGlen);

void PPFGET (int *ishot, char *DDA, char *DTYPE, int *IRDAT,
             char *IHDAT, int *IWDAT, float *DATA,
             float *X, float *T, int *IERR, unsigned int DDAlen, 
	     unsigned int DTYPElen, unsigned int IHDATlen);

void PPFGID (char *username, char *ReadWriteFlag, 
	     unsigned int lengthUsername, unsigned int lengthReadWriteFlag);

void PPFGMD (int *iPulse, int *iSequence, char *caDDAName,
	     int *iNDTin, char *caDTypesIn, char *caBaseVector, 
	     int *iAltVector,
	     int *iNDTout, char *caDTypesOut, char *caVecInfo, int *iNBase,
	     float *faBaseVector, int *iNAlt, float *faAltVector, 
	     float *faData,
	     int *iaErrors, int *iErr,
	     unsigned int DDANameLen, 
	     unsigned int DTypesInLen, unsigned int BaseVectorLen,
	     unsigned int DTypesOutLen, unsigned int VecInfoLen);

void PPFGO  (int *ishot, int *iseq, int *lunit, int *ierr);

void PPFGQI (int *ishot, int *ipqi, int *ierr);

void PPFGSF (int *ishot, int *iseq, char *dda, char *dtype, int *istat,
	     int *ierr, unsigned int dda_length, unsigned int dtype_length);

void PPFGTS (int *ishot, char *DDA, char *DTYPE, float *TWANT, int *IRDAT,
             char *IHDAT, int *IWDAT, float *DATA,
             float *X, float *TGOT, int *IERR, unsigned int DDAlen, 
	     unsigned int DTYPElen, unsigned int IHDATlen);

void PPFINF (int *Shot, int *Seq, int *Lun, int *ncmax,
             int *iwdat, char *icom, int *iErr, int *ndda,
	     char *cdda, unsigned int icom_len, unsigned int icdda_len);

void PPFINI(void);

void PPFKIL (int *ierr);

void PPFMOD (int *Shot, int *iDate, int *iTime, int *iSeq, 
	      int *iModDate, int *iModTime, int *iModSeq, int *iErr);

void PPFNEWPULSE (long int *iShot, long int *iDate, long int *iTime, 
		  int *ierr);

void PPFONDISK (int *ishot, char *DDA, int *iOnDisk,
		int *IERR, unsigned int DDAlen);

void PPFOPN (int *ishot, int *idum1, int *idum2, int *nrmax, int *indat, 
	     char *icom, int *ierr, unsigned int icom_length);

void PPFOWNERINFO (int *iShot, int *iSequence, int *iPublicFlag, char *caOwner,
		   char *caPrevOwner, char *caAuthor, int *iError,
		   unsigned int OwnerLen, unsigned int PrevOwnerLen, unsigned int AuthorLen);
void PPFPOK (int *ierr);

void PPFPRR (int *iprl, int *ipru);

void PPFPWD (char *userID, char *passwd, unsigned int iUserIDLen, 
	     unsigned int ipasswdLen);

void PPFRCM (int *ishot, int *iseq, char *dda, char *dtype, char *comment, 
	     int *ierr, unsigned int dda_length, unsigned int dtype_length, 
	     unsigned int user_comment_length);

void PPFREN (int *ishot, int *iseq, char *caOlduid, char *caNewuid, int *ierr,
	     unsigned int iOlduidLength, unsigned int iNewuidLength);

void PPFSEQ (int *iShot, int *iNumberOfDDAs, char *caDDANames, 
	     int *iaSequenceNums, int *iaModDates, int *iaModTimes,
	     int *iErr, unsigned int iDDANamesLen);

void PPFSIZ (int *iShot, int *iSequence, char *caDDA, char *caUserName,
	     int *iNumberOfPPFs, int *iNumberOfDDAs, int *iNumberOfDataTypes,
	     int *iErr, unsigned int DDALen, unsigned int UserNameLen);

void PPFSQI (int *ishot, int *ipqi, int *ierr);

void PPFSSF (int *ishot, int *iseq, char *dda, char* dtype, int *istat,
	     int *ierr, unsigned int iddaLen, unsigned int idtypeLen);

void PPFSSR (int *istacc, int *nstacc);

void PPFUID (char *username, char *ReadWriteFlag, 
	     unsigned int lengthUsername, unsigned int lengthReadWriteFlag);

void PPFWCM (int *shot, int *seq, char *dda, char *dtype, char *comment, 
	     char *action, int *ierr, unsigned int iDDALen, 
	     unsigned int iDTypeLen, unsigned int iCommentLen, 
	     unsigned int iActionLen);

void PPFWRI (int *Shot, char *DDA, char *DType, int *iRDAT, char *iHDAT,
	     int *iWDAT, float *DATA, float *X, float *T, int *ierr,
	     unsigned int iDDANameLength, unsigned int iDTypeNameLength, 
	     unsigned int iIHDATLength);

void PPFSUM_CLIENT (int iShot, int iSequence, char *caDDAName,
		    char *caUserID, int iPrintX, int iPrintT,
		    int iListing);

/* DEBUGGING ROUTINES */

int PPFDUMPSTATEINFO (void);
int PPFDUMPBACKUPSTATEINFO (void);

#endif

/* User callable PPF client routines */

#ifdef _WIN32

extern void __stdcall DDACLO(int *istat, int *nwc, 
			     char *icom, unsigned int iCommentLength, 
			     int *ierr);
extern void __stdcall DDAINF (int *ishot, char *dda, unsigned int idda_len, 
			      int *nwcom, char *ddacom, unsigned int iddacom_len,
			      int *ndt, char *dtnams, unsigned int idtnams_len,
			      int *lstv, int *iErr);
extern void __stdcall DDAMIN (char *DDA, unsigned int idda_len, int *MRGINF, 
							  int *NWCOM, 
			      char *PPFCOM, unsigned int PPFCOMlen, int *ierr);

extern void __stdcall PDAINF (char *prgnam, unsigned int prgnamlen,
			      int *ipvers, char *ppfnam, unsigned int ppfnamlen,
			      int *ierr);
extern void __stdcall PDAUTH (char *caUserName, unsigned int iUserNameLength, 
			      int *iNumberOfDDAs, int *iNumberOfAlias,
			      int *iNumberOfWriteTo,
			      int *iPrivate, int *iPublic,
			      char *caDDANames, unsigned int DDANameLength,
			      char *caAlias, unsigned int iAliasLength,
			      char *caWriteTo, unsigned int iWriteToLength,
			      int *iErr);
extern void __stdcall PDINFO (int *ishot, int *iseq, int *info, char *cnfo, unsigned int cnfo_length, 
			      char *ddal, unsigned int ddal_length, int *istl, char *pcom,
			      unsigned int pcom_length, char *pdsn, unsigned int pdsn_length,
			      int *ierr);
extern void __stdcall PDLPPF (int *ishot, int *iuid, int *idup, int *nseq, 
			      int *lseq, int *ldda, int *ndda, 
			      char *cdda, unsigned int cdda_length, int *ierr);

extern void __stdcall PDLUSR(int *iShot, char *caDDA, unsigned int DDALen,
			     int *iNumberOfUsers, char *caUserNames,
			     unsigned int UserNameLen, int *iErr);

extern void __stdcall PDMODL (int *iDate, char *caTime, unsigned int TimeLen,
			      int *iNPPFs,  int *iaShot, int *iaSeq,
			      char *caOwner, unsigned int OwnerLen, 
			      int *iaModDate, char *caModTime, 
			      unsigned int ModTimeLen, int *iErr);

extern void __stdcall  PDMODN (int *iDate, char *caTime, unsigned int TimeLen,
			       int *iNPPFs, int *iErr);

extern void __stdcall PDMSEQ(int *iShot, char *caOwner, unsigned int OwnerLen,
			     char *caDDA, unsigned int DDALen, int *iSequence,
			     int *iErr);

extern void __stdcall  PDMSDT (int *iDate, char *caTime, unsigned int TimeLen,
			       int *iPulse, int *iErr);

extern void __stdcall PDMSHT (int *LastShot);

extern void __stdcall PDMTIM (char *caApplication, unsigned int iAppLength,
			      int *iErr);

extern void __stdcall PDNEWL (int *iDate, char *caTime, unsigned int TimeLen,
			      char *caUserName, unsigned int UserLen, 
			      int *iNDDAs,  int *iaShot, int *iaSeq,
			      char *caOwners, unsigned int OwnerLen,
			      char *caDDANames, unsigned int DDALen,
			      int *iErr);

extern void __stdcall PDNEWN (int *iDate, char *caTime, unsigned int TimeLen, 
			      char *caOwner, unsigned int OwnLen, int *iNDDAs, 
			      int *iErr);

extern void __stdcall PDNTIM (char *caApplication, unsigned int iAppLength,
			      int *iErr);

extern void __stdcall PDREFR (int *irefr);
extern void __stdcall PDSRCH (int *ishot, char *dda, 
			      unsigned int dda_length, int *iseq, 
			      int *ndda, char *ddalst, 
			      unsigned int ddalst_length, int *ierr);

extern void __stdcall PDSTAT (char *caLoginName, unsigned int iLoginLength,
			      int *iStatus, char *caStatusString, 
			      unsigned int iStatusLength, int *iErr);

extern void __stdcall PDTINF (int *ishot, char *dda, unsigned int idda_len,
			      int *ndt, char *dtnams, unsigned int idtnams_len,
			      int *lxtv,  char *caDataTypeComments,
			      unsigned int idatatypecommentlength, int *iErr);

extern void __stdcall PDSTD(int *iShot, int *iTime, int *iDate, int *iErr);
extern void __stdcall PPFABO (int *ierr);

extern void __stdcall PPFCLO (int *ISHOT, int *ISEQ, int *idum, 
			      char *PRGNAM, unsigned int prgnamlen,
			      int *IPVERS,int *IERR);
extern void __stdcall PPFDAT (int *ishot, int *iseq, char *dda, 
			      unsigned int dda_length, char *dtype, 
			      unsigned int dtype_length, int *nx, int *nt,
			      float *data, float *x, float *t, int *ierr);

extern void __stdcall PPFDCM(int *shot, int *seq, char *dda, 
			     unsigned int dda_len,
			     char *dtype, unsigned int dtype_len, int *ierr);
extern void __stdcall PPFDDA (int *ishot, char *dda, unsigned int dda_len,
			      int *iseq, int *nseq, int *ierr);

extern void __stdcall PPFDEL (int *iShot, int *iSeq, int *iErr);

extern void __stdcall PPFLISTPPFSOWNEDBYUSER(int iStartShot, int iEndShot, 
					   char *caUserName, 
					   int *iNumberOfSequences, 
					   int *iaPulseNumbers, 
					   int *iaSequenceNumbers, int *iErr);

extern void __stdcall PPFDTI(int *iShot, int *iSequence, char *caDDA,
			     unsigned int DDALen, char *caDataType, 
			     unsigned int DataTypeLen, int *iNX, int *iNT, 
			     char *caFormat, unsigned int FormatLen, 
			     char *caUnits, unsigned int UnitsLen, 
			     char *caComment,unsigned int CommentLen,
			     int *iSystemStatus, int *iUserStatus, int *iErr);

extern void __stdcall PPFEND (int *ishot, int *iseq, int* luint, int *ierr);
extern void __stdcall PPFERR (char *RNAME, unsigned int RNAMElen, 
			      int *ierrcode, char *MSG, unsigned int MSGlen,
			      int *ierr);            
extern void __stdcall PPFGET (int *ishot, char *DDA, unsigned int DDAlen,
			      char *DTYPE, unsigned int DTYPElen, int *IRDAT,
                              char *IHDAT, unsigned int IHDATlen, int *IWDAT, 
			      float *DATA, float *X, float *T, int *IERR);
extern void __stdcall PPFGID (char *username, unsigned int lengthUsername,
			      char *ReadWriteFlag,
			      unsigned int lengthReadWriteFlag);

extern void __stdcall PPFGMD (int *iPulse, int *iSequence, char *caDDAName,
			      unsigned int DDANameLen, int *iNDTin, 
			      char *caDTypesIn, unsigned int DTypesInLen, 
			      char *caBaseVector, unsigned int BaseVectorLen,
			      int *iAltVector, int *iNDTout, char *caDTypesOut,
			      unsigned int DTypesOutLen, char *caVecInfo, 
			      unsigned int VecInfoLen, int *iNBase,
			      float *faBaseVector, int *iNAlt,
			      float *faAltVector, 
			      float *faData, int *iaErrors, int *iErr);

extern void __stdcall PPFGO  (int *ishot, int *iseq, int *lunit, int *ierr);
extern void __stdcall PPFGQI (int *ishot, int *ipqi, int *ierr);
extern void __stdcall PPFGSF (int *ishot, int *iseq, char *dda, 
			      unsigned int dda_length, char *dtype, 
			      unsigned int dtype_length, int *istat,
			      int *ierr);
extern void __stdcall PPFGTS (int *ishot, char *DDA, unsigned int DDAlen, 
			      char *DTYPE, unsigned int DTYPElen, float *TWANT, 
			      int *IRDAT, char *IHDAT, unsigned int IHDATlen,
			      int *IWDAT, float *DATA, float *X, 
			      float *TGOT, int *IERR);
extern void __stdcall PPFINF (int *Shot, int *Seq, int *Lun, int *ncmax,
			      int *iwdat, char *icom, unsigned int icom_len, 
			      int *iErr, int *ndda, char *cdda, 
			      unsigned int icdda_len);
extern void __stdcall PPFINI(void);
extern void __stdcall PPFKIL (int *ierr);

extern void __stdcall PPFMOD  (int *Shot, int *iDate, 
			       int *iTime, int *iSeq, int *iModDate, 
			       int *iModTime, int *iModSeq, int *iErr);

extern void __stdcall PPFNEWPULSE(long int *iShot, long int *iDate, long int *iTime, int *ierr);
extern void __stdcall PPFONDISK (int *ishot, char *DDA, unsigned int DDAlen,
				 int *iOnDisk, int *IERR);
extern void __stdcall PPFOPN (int *ishot, int *idum1, int *idum2, int *NRMAX,
			      int *INDAT, char *ICOM, unsigned int icomlen, 
			      int *IERR);

extern void __stdcall PPFOWNERINFO (int *iShot, int *iSequence, int *iPublicFlag, 
				    char *caOwner, unsigned int OwnerLen,
				    char *caPrevOwner, unsigned int PrevOwnerLen,
				    char *caAuthor, unsigned int AuthorLen, int *iError);

extern void __stdcall PPFPOK (int *ierr);


extern void __stdcall PPFPRR(int *iprl, int *ipru);
extern void __stdcall PPFPWD(char *userID, unsigned int iUserIDLen, char *passwd,
			     unsigned int ipasswdLen);
extern void __stdcall PPFRCM (int *ishot, int *iseq, char *dda, 
			      unsigned int dda_length, char *dtype, 
			      unsigned int dtype_length, char *comment, 
			      unsigned int user_comment_length, int *ierr);

extern void __stdcall PPFREN (int *ishot, int *iseq, char *caOlduid, 
			      unsigned int iOlduidLength, char *caNewuid, 
			      unsigned int iNewuidLength, int *ierr);

extern void __stdcall PPFSEQ (int *iShot, int *iNumberOfDDAs, 
			      char *caDDANames, unsigned int iDDANamesLen,
			      int *iaSequenceNums, int *iaModDates, 
			      int *iaModTimes,
			      int *iErr);

extern void __stdcall PPFSIZ(int *iShot, int *iSequence, char *caDDA, 
			     unsigned int DDALen, char *caUserName,
			     unsigned int UserNameLen, int *iNumberOfPPFs,
			     int *iNumberOfDDAs, int *iNumberOfDataTypes,
			     int *iErr);

extern void __stdcall PPFSQI (int *ishot, int *ipqi, int *ierr);
extern void __stdcall PPFSSF (int *ishot, int *iseq, char *dda, 
			      unsigned int iddaLen, char* dtype, unsigned int idtypeLen,
			      int *istat, int *ierr);
extern void __stdcall PPFSSR(int *istacc, int *nstacc);

extern void __stdcall PPFUID (char *Username, unsigned int lengthUsername,
			      char *ReadWriteFlag, 
			      unsigned int lengthReadWriteFlag);
extern void __stdcall PPFWCM(int *shot, int *seq, char *dda, unsigned int iDDALen,
			     char *dtype, unsigned int iDTypeLen, char *comment, 
                             unsigned int iCommentLen, char *action, 
			     unsigned int iActionLen, int *ierr);
extern void __stdcall PPFWRI(int *Shot, char *DDA, unsigned int iDDANameLength, 
			     char *DType, unsigned int iDTypeNameLength,
			     int *iRDAT, char *iHDAT, unsigned int iIHDATLength, 
			     int *iWDAT, float *DATA, float *X, float *T, 
			     int *ierr);

/* DEBUGGING ROUTINES */

#endif
