/*
 * PPF c++ wrapper
 *
 * Copyright (C) 2008 Alex Meakins
 *
 * 2008-04-09: Alex Meakins <alex.meakins@jet.uk>
 *             initial version
 *
 * This file is part of PPFc++.
 *
 * PPFc++ is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PPFc++ is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser Public License for more details.
 *
 * You should have received a copy of the GNU Lesser Public License
 * along with PPFc++.  If not, see <http://www.gnu.org/licenses/>.
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 */

#include <iostream>
#include <fstream>
#include <string>
#include <cmath>
#include <cstdio>
#include "ppfc++.hpp"

using namespace std;
using namespace ppf;

int main(int argc, char *argv[])
{
	long n;
	double tmin, dt;
	string name;
	datatype a;
	ofstream f;

	if (argc != 5)
	{
		cout << "Usage: ppfdump [SHOT NUMBER] [DDA] [DTYPE] [POINTS]\n";
		exit(1);
	}

	if (atol(argv[1]) < 0) 
	{
		cout << "Error: shot number cannot be less than zero.";
		exit(1);
	}

	n = atol(argv[4]);

	if (n < 2) 
	{
		cout << "Error: must have at least 2 points.";
		exit(1);
	}

	try
	{
		cerr << "Connecting...";
		ppfdb.connect();
		cerr << "DONE!\n";

		cerr << "Reading PPF..";
		ppfdb.read(a, atol(argv[1]), argv[2], argv[3]);
		cerr << "DONE!\n";

		cerr << "Dumping PPF...";
		tmin = a.getT(0);
		dt = (a.getT(a.sizeT()-1) - tmin) / double(n-1);
		name = string(argv[1]) + "_" + string(argv[2]) + "_" + string(argv[3]) + ".txt";
		f.open(name.c_str());
		for (long i=0;i<n;i++) 
		{
			f << (i *dt + tmin) << "\t";
			for (long j=0;j<a.sizeX();j++) f << a.getDataTIx(i * dt + tmin, j) << "\t";
			f << endl;
		}
		f.close();
		cerr << "DONE!\n";
	}
	catch (ppf_error &e)
	{
		cout << "Error: " << e.message << " Code=" << e.code << ", Routine=" << e.method << endl;
		exit(1);
	}

   	return 0;
}


